<?php
  /**
   * Třída sloužící k získávání informací o konkrétních uživatelích,
   * k přidávání nových uživatelů a dalším souvisejícím operacím.
   *
   * @author Martin Šebela
   */
  class UsersModel {
    /**
     * @var string      Název tabulky v databázi, se kterou je instance svázána.
     */
    private $dbTableName = 'blck_users';

    /**
     * @var string      Uživatelské jméno.
     */
    public $username;

    /**
     * @var string      E-mail uživatele.
     */
    public $email;


    /**
     * Připraví nového uživatele v závislosti na vyplněných datech a vrátí ho formou pole.
     *
     * @return array                   Pole obsahující data o uživateli.
     */
    private function makeUser() {
      // Pokud dochází k registraci nového uživatele, je třeba mu vytvořit uživatelské jméno pro přihlášení.
      if (empty($this->dbRecordData['username'])) {
        $this->username = get_email_part($this->email, 'username');
        $user['username'] = $this->username;
      }

      return $user;
    }


    /**
     * Uloží do instance a zároveň vrátí (z databáze) informace o uživateli na základě jeho ID.
     *
     * @param int $id                  ID uživatele.
     * @return array                   Pole s informacemi o uživateli.
     */
    public function getUser($id) {
      $this->dbRecordData = Database::querySingle('
              SELECT `id_user`, `username`
              FROM `blck_users`
              WHERE `id_user` = ?
              AND `visible` = 1
      ', $id);

      return $this->dbRecordData;
    }


    /**
     * Vrátí informace o uživateli na základě jeho uživatelského jména.
     *
     * @param string $username         Uživatelské jméno.
     * @return mixed                   Pole s informacemi o uživateli.
     */
    public static function getUserByUsername($username) {
      return Database::querySingle('
              SELECT `id_user`, `username`
              FROM `blck_users`
              WHERE `username` = ?
              AND `visible` = 1
      ', $username);
    }


    /**
     * Vrátí počet všech aktivních uživatelů (nesmazaných).
     *
     * @return mixed                   Počet aktivních uživatelů
     */
    public static function getCountOfActiveUsers() {
      return Database::queryCount('
              SELECT COUNT(*)
              FROM `blck_users`
              WHERE `visible` = 1
      ');
    }


    /**
     * Vloží do databáze nového uživatele.
     */
    public function insertUser() {
      $user = $this->makeUser();

      $user['date_added'] = date('Y-m-d H:i:s');

      Logger::info('Vkládání nového uživatele.', $user);

      Database::insert($this->dbTableName, $user);
    }
  }
