<?php
  /**
   * Rozhraní, které musí splňovat (implementovat) každý nový modul pro blokaci a odblokování.
   * Jednotlivé metody modulu jsou následně volány aplikací Blockator.
   *
   * @author Martin Šebela
   */
  interface IBlocker {
    /**
     * Vrátí název (označení) sítě pro textové výpisy.
     *
     * @return string                  Název sítě.
     */
    public function getNetworkName();


    /**
     * Vrátí, zdali hostname spadá do rozsahu sítě (daného modulu).
     *
     * @param string $hostname         Hostname zařízení.
     * @return bool                    TRUE pokud spadá do oblasti sítě, jinak FALSE.
     */
    public function isFromThisNetwork($hostname);


    /**
     * Zařídí vyhledávání záznamů v logu o dané IP adrese v určitém datu a nalezená data vrátí.
     *
     * @param string $ipAddress        IP adresa.
     * @param string $macAddress       MAC adresa (nemá význam, nebude použita).
     * @param string $datetime         Datum a čas.
     * @return array                   Nalezená data v logu.
     */
    public function find($ipAddress, $macAddress, $datetime);


    /**
     * Zablokuje konkrétního uživatele v dané síti.
     *
     * @param BlockedIdentity $identity Identita, která se má zablokovat.
     * @return bool                     TRUE při úspěšné blokaci.
     * @throws UserError                Výjimka obsahující textovou informaci o chybě pro uživatele.
     */
    public function block(BlockedIdentity $identity);


    /**
     * Odblokuje konkrétního uživatele v dané síti.
     *
     * @param BlockedIdentity $identity Identita, která se má odblokovat.
     * @return bool                     TRUE při úspěšném odblokování.
     * @throws UserError                Výjimka obsahující textovou informaci o chybě pro uživatele.
     */
    public function unblock(BlockedIdentity $identity);
  }